==> zio-aws-eks_2.12-5.17.155.2-sources.jar: zio/aws/eks/model/UpdateNodegroupConfigResponse.scala <==
package zio.aws.eks.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateNodegroupConfigResponse(
    update: Option[zio.aws.eks.model.Update] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse = {
    import UpdateNodegroupConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse
      .builder()
      .optionallyWith(update.map(value => value.buildAwsValue()))(_.update)
      .build()
  }
  def asReadOnly: zio.aws.eks.model.UpdateNodegroupConfigResponse.ReadOnly =
    zio.aws.eks.model.UpdateNodegroupConfigResponse.wrap(buildAwsValue())
}
object UpdateNodegroupConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.eks.model.UpdateNodegroupConfigResponse =
      zio.aws.eks.model
        .UpdateNodegroupConfigResponse(update.map(value => value.asEditable))
    def update: Option[zio.aws.eks.model.Update.ReadOnly]
    def getUpdate: ZIO[Any, AwsError, zio.aws.eks.model.Update.ReadOnly] =
      AwsError.unwrapOptionField("update", update)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse
  ) extends zio.aws.eks.model.UpdateNodegroupConfigResponse.ReadOnly {
    override val update: Option[zio.aws.eks.model.Update.ReadOnly] = scala
      .Option(impl.update())
      .map(value => zio.aws.eks.model.Update.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse
  ): zio.aws.eks.model.UpdateNodegroupConfigResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-eks_2.13-5.17.212.1-sources.jar: zio/aws/eks/model/UpdateNodegroupConfigResponse.scala <==
package zio.aws.eks.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateNodegroupConfigResponse(
    update: Optional[zio.aws.eks.model.Update] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse = {
    import UpdateNodegroupConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse
      .builder()
      .optionallyWith(update.map(value => value.buildAwsValue()))(_.update)
      .build()
  }
  def asReadOnly: zio.aws.eks.model.UpdateNodegroupConfigResponse.ReadOnly =
    zio.aws.eks.model.UpdateNodegroupConfigResponse.wrap(buildAwsValue())
}
object UpdateNodegroupConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.eks.model.UpdateNodegroupConfigResponse =
      zio.aws.eks.model
        .UpdateNodegroupConfigResponse(update.map(value => value.asEditable))
    def update: Optional[zio.aws.eks.model.Update.ReadOnly]
    def getUpdate: ZIO[Any, AwsError, zio.aws.eks.model.Update.ReadOnly] =
      AwsError.unwrapOptionField("update", update)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse
  ) extends zio.aws.eks.model.UpdateNodegroupConfigResponse.ReadOnly {
    override val update: Optional[zio.aws.eks.model.Update.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.update())
        .map(value => zio.aws.eks.model.Update.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.eks.model.UpdateNodegroupConfigResponse
  ): zio.aws.eks.model.UpdateNodegroupConfigResponse.ReadOnly = new Wrapper(
    impl
  )
}
